"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Errors_1 = require("./supportObjects/Errors");
const restify_errors_1 = require("restify-errors");
class OracleDBErrorParser {
    static isOracleError(error) {
        return error.message.startsWith('ORA');
    }
    static parseError(message) {
        const parsedError = {
            message: message,
            errorCode: undefined
        };
        const messageNoBreaks = message.replace(/(\r\n|\n|\r)/gm, '');
        // Permission issue case
        if (messageNoBreaks.includes('Access denied') && messageNoBreaks.includes('ORA-20202')) {
            parsedError.message = this.parseMessage(messageNoBreaks, /(ORA-20202:)(.*?)(ORA)/);
            parsedError.errorCode = Errors_1.OracleErrorCodes.ORA20202;
            return parsedError;
        }
        else if (messageNoBreaks.includes('Access denied')) {
            parsedError.message = this.parseMessage(messageNoBreaks, /(:)(.*?)(ORA)/);
            return parsedError;
        }
        if (messageNoBreaks.includes('ORA-20001: ERROR=ORA-20001: ERROR=ORA-20001: ERROR=ORA-20110:')) {
            parsedError.message = this.parseMessage(messageNoBreaks, /(ORA-20001: ERROR=ORA-20001: ERROR=ORA-20001: ERROR=ORA-20110:)(.*?)(ORA)/);
            parsedError.errorCode = Errors_1.OracleErrorCodes.ORA20001;
            return parsedError;
        }
        if (messageNoBreaks.includes(Errors_1.OracleErrorCodes.ORA20110)) {
            parsedError.message = this.parseMessage(messageNoBreaks, new RegExp(`(${Errors_1.OracleErrorCodes.ORA20110}:)(.*?)(ORA)`));
            parsedError.errorCode = Errors_1.OracleErrorCodes.ORA20110;
            return parsedError;
        }
        if (messageNoBreaks.includes(Errors_1.OracleErrorCodes.ORA20111)) {
            parsedError.message = this.parseMessage(messageNoBreaks, new RegExp(`(${Errors_1.OracleErrorCodes.ORA20111}:)(.*?)(ORA)`));
            parsedError.errorCode = Errors_1.OracleErrorCodes.ORA20111;
            return parsedError;
        }
        if (messageNoBreaks.includes(Errors_1.OracleErrorCodes.ORA20003)) {
            parsedError.message = this.parseMessage(messageNoBreaks, new RegExp(`(${Errors_1.OracleErrorCodes.ORA20003}:)(.*?)(ORA)`));
            parsedError.errorCode = Errors_1.OracleErrorCodes.ORA20003;
            return parsedError;
        }
        if (messageNoBreaks.includes('ERROR=')) {
            parsedError.message = this.parseMessage(messageNoBreaks, /(ERROR=)(.*?)(ORA)/);
            return parsedError;
        }
        return parsedError;
    }
    static parseMessage(message, regex) {
        const parsedMessage = message.match(regex);
        return parsedMessage[2] ? parsedMessage[2].trim() : message;
    }
    static getHttpErrorByErrorCode(errorCode) {
        switch (errorCode) {
            case Errors_1.OracleErrorCodes.ORA20111:
                return restify_errors_1.ConflictError;
            default:
                return undefined;
        }
    }
}
exports.default = OracleDBErrorParser;
//# sourceMappingURL=OracleDBErrorParser.js.map