"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OracleDBRequestParameters = void 0;
const Errors_1 = require("./supportObjects/Errors");
const Parameters_1 = require("./Parameters");
/**
 * Parameters for passing to Oracle db stored procedure.
 *
 */
class OracleDBRequestParameters {
    constructor() {
        this._filter = new Array();
        this._fields = new Array();
        this._sort = new Array();
        this._offset = 0;
        this._limit = 1000;
    }
    setFiltersFromQueryParameters(queryParameters) {
        if (queryParameters.filter === undefined) {
            return;
        }
        try {
            // TODO write validator
            this._filter = JSON.parse(queryParameters.filter);
        }
        catch (err) {
            Parameters_1.default.logger.error('Error parsing filter details: ' + err.message);
            throw new Errors_1.BadInputError('Wrong filter format provided.');
        }
    }
    setFieldsToBeReturendFromQueryParameters(queryParameters) {
        if (queryParameters.fields === undefined) {
            return;
        }
        try {
            this._fields = JSON.parse(queryParameters.fields);
        }
        catch (err) {
            Parameters_1.default.logger.error('Error parsing list of fields: ' + err.message);
            throw new Errors_1.BadInputError('Wrong fields format provided.');
        }
    }
    setSortFromQueryParameters(queryParameters) {
        if (queryParameters.sort === undefined) {
            return;
        }
        try {
            this._sort = JSON.parse(queryParameters.sort);
        }
        catch (err) {
            Parameters_1.default.logger.error('Error parsing sort values: ' + err.message);
            throw new Errors_1.BadInputError('Wrong sort format provided.');
        }
    }
    setLimitFromQueryParameters(queryParameters) {
        if (queryParameters.limit === undefined || queryParameters.limit.length === 0) {
            return;
        }
        this._limit = parseInt(queryParameters.limit);
    }
    setOffsetFromQueryParameters(queryParameters) {
        if (queryParameters.start === undefined || queryParameters.start.length === 0) {
            return;
        }
        this._offset = parseInt(queryParameters.start) + 1;
    }
    setItemIdFromPathParameters(pathParams) {
        this._itemId = pathParams.id;
    }
    parseQueryParams(queryParameters) {
        this.setFiltersFromQueryParameters(queryParameters);
        this.setFieldsToBeReturendFromQueryParameters(queryParameters);
        this.setSortFromQueryParameters(queryParameters);
        this.setLimitFromQueryParameters(queryParameters);
        this.setOffsetFromQueryParameters(queryParameters);
    }
    get filter() {
        return this._filter;
    }
    set filter(value) {
        this._filter = value;
    }
    get fields() {
        return this._fields;
    }
    set fields(value) {
        this._fields = value;
    }
    get sort() {
        return this._sort;
    }
    set sort(value) {
        this._sort = value;
    }
    get itemId() {
        return this._itemId;
    }
    set itemId(value) {
        this._itemId = value;
    }
    get offset() {
        return this._offset;
    }
    set offset(value) {
        this._offset = value;
    }
    get limit() {
        return (this._limit === null) ? 10000 : this._limit;
    }
    set limit(value) {
        this._limit = value;
    }
}
exports.OracleDBRequestParameters = OracleDBRequestParameters;
//# sourceMappingURL=OracleDBRequestParameters.js.map